<template>
  <div class="main">
    <div class="search">
      <van-dropdown-menu class="dropdown">
        <van-dropdown-item v-model="param.querys[0].value" :options="option1" style="width: 30%;"
                           @change="onSearch" />
      </van-dropdown-menu>
      <van-search style="width:65%" v-model="param.querys[1].value" placeholder="请输入计划名称" @blur="onSearch" />
    </div>
    <van-pull-refresh style="padding-top: 2.5rem;box-sizing: border-box;" v-model="refreshing" @refresh="onRefresh" class="van-hairline--top">
      <van-list :style="{'padding-top': refreshing ? 0: '1.5rem'}" v-model="loading" :finished="finished"
                finished-text="没有更多了" @load="onLoad">
        <div class="table-item" v-for="(item, index) in list" :key="index">
          <div class="title">
            <div>{{ item.planName }}</div>
            <!-- <div>
            <van-tag v-if="item.taskType == '1'" color="#999" text-color="#fff">日常巡检</van-tag>
            <van-tag v-if="item.taskType == '2'" type="primary">定期巡检</van-tag>
            <van-tag v-if="item.taskType == '3'" type="warning">特殊巡检</van-tag>
        </div> -->
          </div>
          <div class="two-title">巡检内容：{{ item.taskContent }}</div>
          <div class="card-bottom">
            <div class="two-title">任务时间：{{ item.taskDate }}</div>
            <div class="two-title" style="text-align: right;padding-right: 5px;">
              <span style="color: #4a9f09;font-weight: bold;">{{ item.finishNum }}</span>
              <span style="font-weight: bold;"> / </span>
              <span style="color: #01affd;font-weight: bold;">{{ item.totalNum }}</span>
            </div>
          </div>

          <div class="card-bottom card-height">
            <div>
              <van-tag v-if="item.taskType == '1'" color="#999" text-color="#fff">日常巡检</van-tag>
              <van-tag v-if="item.taskType == '2'" type="primary">定期巡检</van-tag>
              <van-tag v-if="item.taskType == '3'" type="warning">特殊巡检</van-tag>
            </div>
            <div class="tast-status">
              <template v-if="item.fillStatus < 2">
                <van-tag v-if="item.taskStatus === 0" color="#999" text-color="#fff">未开始</van-tag>
                <van-tag v-if="item.taskStatus === 1" type="primary">执行中</van-tag>
              </template>
              <van-tag v-else type="success">已完成</van-tag>
            </div>
            <div class="action">
              <van-button v-if="item.taskStatus === 0" type="default"
                          @click="receivingTask(item)">接收</van-button>
              <van-button v-if="item.taskStatus === 1" type="primary"
                          @click="toDetail(item)">录入</van-button>
              <van-button v-if="item.taskStatus === 2"
                          style="color: #fff;background-color: #1989fa;border: 1px solid #1989fa;"
                          @click="toDetail(item)">编辑</van-button>
            </div>
          </div>

        </div>
      </van-list>
    </van-pull-refresh>
  </div>
</template>
<script>
import api from '@/api/device/Inspection.js'
import { param } from 'jquery';
import { Dialog } from 'vant';
import navBar from '@/views/Mobile/components/navBar.vue'
export default {
  name: 'AskForLeave',
  components: {navBar},
  data() {
    return {
      value: '',
      value1: '',
      option1: [
        { text: '全部', value: '' },
        { text: '日常巡检', value: '1' },
        { text: '定期巡检', value: '2' },
        { text: '特殊巡检', value: '3' },
      ],

      list: [],
      loading: false,
      finished: false,
      total: 0,
      queryParam: {
        inspectionType: '',
        inspectionPlanName: ''
      },
      param: {
        pageBean: {
          page: 0,
          pageSize: 20,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: "",
            property: "task_Type_",
            relation: "AND",
            value: ''
          },
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: "",
            property: "plan_Name_",
            relation: "AND",
            value: ''
          }
        ],
      },
      refreshing: false
    }
  },
  created() {

  },
  methods: {
    onRefresh() {
      setTimeout(() => {
        this.param.pageBean.page = 1
        this.refreshing = true
        this.list = []
        this.getData()
      }, 500)
    },
    // 接收任务
    receivingTask(row) {
      Dialog.confirm({
        title: '提示',
        message:
          '确认接收任务吗？',
      }).then(() => {
        this.loading = true
        api.receivingTask({ id: row.id, status: 1 }, res => {
          if (res.state) {
            this.$message.success('接收任务成功！')
            row.taskStatus = 1
          }
          this.loading = false
        })
      })
    },
    onLoad() {
      setTimeout(() => {
        this.param.pageBean.page += 1
        if (!this.finished) {
          this.getData()
        }
        this.loading = false;
      }, 500);
    },
    onSearch() {
      this.finished = false;
      this.param.pageBean.page = 1
      this.list = []
      this.getData()
    },
    getData() {
      api.inspectionTask(this.param, res => {
        if (res.rows) {
          this.list = [...this.list, ...res.rows]
          this.total = res.total
          if (this.list.length >= this.total) {
            this.finished = true;
          }
        }
        this.refreshing = false
      })
    },
    toDetail(val) {
      if (val.taskStatus) {
        this.$router.push({name: 'InspectionFacility', query: {id: val.id}})
      }
    }

  },
}
</script>
<style lang="scss" scoped>
.search {
  width: 100%;
  position: fixed;
  display: flex;
  background-color: #fff;
  justify-content: space-between;
  top: 9vw;
  box-shadow: 0 2px 12px rgba(100, 101, 102, .12);
  z-index: 9;

  .dropdown {
    box-shadow: none;
    width: 30%;
  }
}

.table-item {
  background: #fff;
  box-shadow: 0 0 .5rem .2rem rgba(82, 81, 81, 0.11);
  border-radius: 1rem;
  margin: 1rem .7rem;
  padding: 1rem;
  box-sizing: border-box;

  .title {
    display: flex;
    justify-content: space-between;
    padding: 10px 0;
    // line-height: 3rem;

    div:nth-child(1) {
      font-weight: bold;
    }

  }

  .two-title {
    color: #7e7d7d;
    line-height: 2rem;
  }

  .card-height {
    height: 3rem;
  }

  .card-bottom {
    display: flex;
    justify-content: space-between;
    align-items: center;

    > div {
      flex: 1;
    }

    .time {
      color: #7e7d7d;
    }

    .tast-status {
      text-align: center;
    }

    .action {
      text-align: right;

      ::v-deep.van-button {
        padding: 8px 40px;
        height: 25PX !important;
        //height: fit-content !important;
      }
    }
  }


}

::v-deep .van-search {
  padding: 0 1rem 0 0;
}

::v-deep .van-dropdown-menu__bar {
  box-shadow: none
}

::v-deep .van-tag {
  position: static;
}
</style>